@@ -5,7 +5,7 @@ extern i_img *
 imss_win32(unsigned hwnd, int include_decor, int left, int top, int right, int bottom, int display);
 
 extern i_img *
-imss_x11(unsigned long display, int window_id, int left, int top, int right, int bottom);
+imss_x11(unsigned long display, int window_id, int left, int top, int right, int bottom, int direct);
 
 extern unsigned long
 imss_x11_open(char const *display_name);
